==> tmw-0.0.27.tar.gz: tmw-0.0.27/src/gui/itemshortcutwindow.h <==
/*
 *  The Mana World
 *  Copyright 2007 The Mana World Development Team
 *
 *  This file is part of The Mana World.
 *
 *  The Mana World is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  The Mana World is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with The Mana World; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _TMW_ITEMSHORTCUTWINDOW_H
#define _TMW_ITEMSHORTCUTWINDOW_H

#include "window.h"

class ItemShortcutContainer;
class ScrollArea;

/**
 * A window around the ItemShortcutContainer.
 *
 * \ingroup Interface
 */
class ItemShortcutWindow : public Window
{
    public:
        /**
         * Constructor.
         */
        ItemShortcutWindow();

        /**
         * Destructor.
         */
        ~ItemShortcutWindow();

        /**
         * Called whenever the widget changes size.
         */
        void widgetResized(const gcn::Event &event);

    private:
        ItemShortcutContainer *mItems;

        ScrollArea *mScrollArea;
};

extern ItemShortcutWindow *itemShortcutWindow;

#endif

==> tmw_0.0.28.1.orig.tar.gz: tmw-0.0.28.1/src/gui/itemshortcutwindow.h <==
/*
 *  The Mana World
 *  Copyright (C) 2007  The Mana World Development Team
 *
 *  This file is part of The Mana World.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef ITEMSHORTCUTWINDOW_H
#define ITEMSHORTCUTWINDOW_H

#include "window.h"

class ItemShortcutContainer;
class ScrollArea;

/**
 * A window around the ItemShortcutContainer.
 *
 * \ingroup Interface
 */
class ItemShortcutWindow : public Window
{
    public:
        /**
         * Constructor.
         */
        ItemShortcutWindow();

        /**
         * Destructor.
         */
        ~ItemShortcutWindow();

        /**
         * Called whenever the widget changes size.
         */
        void widgetResized(const gcn::Event &event);

    private:
        ItemShortcutContainer *mItems;

        ScrollArea *mScrollArea;
};

extern ItemShortcutWindow *itemShortcutWindow;

#endif
